//
//  ViewController.swift
//  Aufgabenliste
//
//  Created by Holger Hinzberg on 06.11.17.
//  Copyright © 2017 Holger Hinzberg. All rights reserved.
//


import UIKit

class TabellenViewController: UITableViewController, TabellenViewProtokoll
{
    var aufgabenAblage : Aufgabenablage?
    // Eine Eigenschaft für die ausgewählte Aufgabe
    var gewaehlteAufgabe: Aufgabe?
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        self.aufgabenAblage = Aufgabenablage()
    }
        
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int
    {
        return self.aufgabenAblage!.anzahlDerAufgaben()
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell
    {
        // Eine Aufgabe an der angegebenen Position
        // aus der Aufgabenablage holen
        let aufgabe = self.aufgabenAblage!.aufgabeAn(position: indexPath.row)
        let zelle = tableView.dequeueReusableCell(withIdentifier: "Zelle") as? Aufgabenzelle
        
        // Der Titel der Aufgabe wir dre Text der Zelle
        zelle?.titelLabel?.text = aufgabe?.Titel
        
        switch aufgabe!.Prioritaet
        {
        case Dringlichkeit.SehrWichtig:
            zelle?.prioritaetView?.backgroundColor = UIColor.red
        case Dringlichkeit.Wichtig:
            zelle?.prioritaetView?.backgroundColor = UIColor.yellow
        default:
            zelle?.prioritaetView?.backgroundColor = UIColor.green
        }
        
        return zelle!
    }
    
    override func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat
    {
        return 60
    }
    
    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath)
    {
        let aufgabe = self.aufgabenAblage!.aufgabeAn(position: indexPath.row)
        if let aufgabe = aufgabe
        {
            print(aufgabe.Titel)
            self.gewaehlteAufgabe = aufgabe
            // Den Segue mit dem angegebenen Identifier ausführen
            self.performSegue(withIdentifier: "ZurDetailAnsicht", sender: nil)
        }
    }
    
    @IBAction func neueAufgabeButtonBeruehrt(_ sender: Any)
    {
        // Es gibt keine gewählte Aufgabe
        self.gewaehlteAufgabe = nil
        
        // Den Segue mit dem angegebenen Identifier ausführen
        self.performSegue(withIdentifier: "ZurDetailAnsicht", sender: nil)
    }
    
    func aufgabeEinfuegen(aufgabe:Aufgabe)
    {
        // Die Aufgabe der Ablage hinzufügen
        self.aufgabenAblage?.hinzufügen(aufgabe: aufgabe)
        // Das Tabellensteuerelement aktualisieren
        self.tableView.reloadData()
        // Die Aufgabenablage speichern
        self.aufgabenAblage?.speichern()
    }
    
    func aktualisieren()
    {
        // Das Tabellensteuerelement aktualisieren
        self.tableView.reloadData()
        // Die Aufgabenablge speichern
        self.aufgabenAblage?.speichern()
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?)
    {
        if segue.identifier == "ZurDetailAnsicht"
        {
            if let ziel = segue.destination as? DetailViewController
            {
                // Der TabellenViewController übergibt sich
                // selbst als Verweis an den
                // DetailViewController
                ziel.tabellenUebersicht = self
            }
        }
    }
    
    override func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool
    {
        // Jede Zelle darf bearbeitet werden
        return true
    }
    
    override func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath)
    {
        if editingStyle == UITableViewCellEditingStyle.delete
        {
            // Aufgabe an der angegebenen Position entfernen
            self.aufgabenAblage?.entfernen(position: indexPath.row)
            
            // let aufgabe = self.aufgabenAblage?.aufgabeAn(position: indexPath.row)
            // self.aufgabenAblage?.entfernen(aufgabe: aufgabe!)
            
            // Die Aufgabenablge speichern
            self.aufgabenAblage?.speichern()
            
            // Eine Zelle aus der Tabelle löschen
            tableView.deleteRows(at: [indexPath], with: UITableViewRowAnimation.automatic )
        }
    }
   
    override func tableView(_ tableView: UITableView, titleForDeleteConfirmationButtonForRowAt indexPath: IndexPath) -> String?
    {
            return "Löschen"
    }

    
    
}

